# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: private_controller.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import messages_pb2 as messages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='private_controller.proto',
  package='robotc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18private_controller.proto\x12\x06robotc\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0emessages.proto\"4\n\x13\x45nableJointBacklash\x12\r\n\x05joint\x18\x01 \x01(\x05\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\"D\n\x15\x45nableJointBacklashes\x12+\n\x06joints\x18\x01 \x03(\x0b\x32\x1b.robotc.EnableJointBacklash\"\xef\x01\n\x0f\x45xtraServoParam\x12\r\n\x05joint\x18\x01 \x01(\x05\x12\x17\n\x0f\x61\x63\x63_position_kp\x18\x02 \x01(\x01\x12\x14\n\x0c\x61\x63\x63_speed_kp\x18\x03 \x01(\x01\x12\x14\n\x0c\x61\x63\x63_speed_it\x18\x04 \x01(\x01\x12\x17\n\x0funi_position_kp\x18\x05 \x01(\x01\x12\x14\n\x0cuni_speed_kp\x18\x06 \x01(\x01\x12\x14\n\x0cuni_speed_it\x18\x07 \x01(\x01\x12\x17\n\x0f\x64\x65\x63_position_kp\x18\x08 \x01(\x01\x12\x14\n\x0c\x64\x65\x63_speed_kp\x18\t \x01(\x01\x12\x14\n\x0c\x64\x65\x63_speed_it\x18\n \x01(\x01\";\n\x10\x45xtraServoParams\x12\'\n\x06joints\x18\x01 \x03(\x0b\x32\x17.robotc.ExtraServoParam\"Y\n\rJointBacklash\x12\r\n\x05joint\x18\x01 \x01(\x05\x12\t\n\x01k\x18\x02 \x01(\r\x12\n\n\x02iq\x18\x03 \x01(\x01\x12\x10\n\x08iq_final\x18\x04 \x01(\x01\x12\x10\n\x08iq_count\x18\x05 \x01(\r\"8\n\x0fJointBacklashes\x12%\n\x06joints\x18\x01 \x03(\x0b\x32\x15.robotc.JointBacklash\"v\n\x12JointBacklashParam\x12\r\n\x05joint\x18\x01 \x01(\x05\x12\x1b\n\x13\x65ncoder_data_offset\x18\x02 \x01(\x05\x12\n\n\x02on\x18\x03 \x01(\r\x12\x0c\n\x04over\x18\x04 \x01(\r\x12\r\n\x05leave\x18\x05 \x01(\r\x12\x0b\n\x03max\x18\x06 \x01(\r\"A\n\x13JointBacklashParams\x12*\n\x06joints\x18\x01 \x03(\x0b\x32\x1a.robotc.JointBacklashParam\"2\n\tVoiceFile\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x0b\n\x03md5\x18\x03 \x01(\t\"=\n\x0bVoiceResult\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04step\x18\x02 \x01(\x05\x12\x14\n\x0cstepProgress\x18\x03 \x01(\x05\"\x1a\n\x0bTrueOrFalse\x12\x0b\n\x03val\x18\x01 \x01(\x08\"%\n\x10InstallDirection\x12\x11\n\tdirection\x18\x01 \x01(\x05\"O\n\x0bJointConfig\x12\x10\n\x08maxAngle\x18\x01 \x01(\x01\x12\x10\n\x08minAngle\x18\x02 \x01(\x01\x12\x0c\n\x04maxV\x18\x03 \x01(\x01\x12\x0e\n\x06maxAcc\x18\x04 \x01(\x01\"4\n\x0cJointConfigs\x12$\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\x13.robotc.JointConfig\"/\n\x0f\x43\x61rtesianConfig\x12\x0c\n\x04maxV\x18\x01 \x01(\x01\x12\x0e\n\x06maxAcc\x18\x02 \x01(\x01\"0\n\nSafetyPlat\x12\"\n\x06points\x18\x01 \x03(\x0b\x32\x12.robotc.Coordinate\"0\n\x0bSafetyPlats\x12!\n\x05plats\x18\x01 \x03(\x0b\x32\x12.robotc.SafetyPlat\"$\n\x13\x43ollisionTorqueDiff\x12\r\n\x05\x64iffs\x18\x01 \x03(\x01\"[\n\x11\x43ollisionDetector\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\x12\x11\n\tpauseTime\x18\x03 \x01(\x05\x12\x13\n\x0bsensitivity\x18\x04 \x01(\x05\"h\n\x08LEDStyle\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\r\n\x05speed\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x03(\x05\x12\r\n\x05voice\x18\x01 \x01(\x05\x12\x0e\n\x06volume\x18\x02 \x01(\x05\x12\x11\n\trobotMode\x18\x06 \x01(\x05\"-\n\tLEDStyles\x12 \n\x06styles\x18\x10 \x03(\x0b\x32\x10.robotc.LEDStyle\"N\n\x0c\x42uttonConfig\x12\x12\n\nbtn_flan_1\x18\x01 \x01(\x08\x12\x12\n\nbtn_flan_2\x18\x02 \x01(\x08\x12\x16\n\x0e\x62tn_shoulder_0\x18\x03 \x01(\x08\"\xbb\x06\n\rConfiguration\x12\x32\n\x10installDirection\x18\x01 \x01(\x0b\x32\x18.robotc.InstallDirection\x12\x34\n\x11\x63ollisionDetector\x18\x02 \x01(\x0b\x32\x19.robotc.CollisionDetector\x12*\n\x0cjointConfigs\x18\x03 \x01(\x0b\x32\x14.robotc.JointConfigs\x12(\n\x0bsafetyPlats\x18\x04 \x01(\x0b\x32\x13.robotc.SafetyPlats\x12\x17\n\x03tcp\x18\x05 \x01(\x0b\x32\n.robotc.PR\x12 \n\x07payload\x18\x06 \x01(\x0b\x32\x0f.robotc.Payload\x12\x11\n\tenableDDS\x18\x07 \x01(\x08\x12\x38\n\x13\x63ollisionTorqueDiff\x18\x08 \x01(\x0b\x32\x1b.robotc.CollisionTorqueDiff\x12\x15\n\rrobotDIOInNum\x18\t \x01(\x05\x12\x16\n\x0erobotDIOOutNum\x18\n \x01(\x05\x12%\n\x10robotAIOInConfig\x18\x0b \x03(\x0b\x32\x0b.robotc.AIO\x12&\n\x11robotAIOOutConfig\x18\x0c \x03(\x0b\x32\x0b.robotc.AIO\x12\x13\n\x0btcpDIOInNum\x18\r \x01(\x05\x12\x14\n\x0ctcpDIOOutNum\x18\x0e \x01(\x05\x12\r\n\x05zeros\x18\x0f \x03(\x01\x12 \n\x06styles\x18\x10 \x03(\x0b\x32\x10.robotc.LEDStyle\x12\x13\n\x0b\x62reak_a_cup\x18\x11 \x01(\x08\x12+\n\rbutton_config\x18\x12 \x01(\x0b\x32\x14.robotc.ButtonConfig\x12\x30\n\x0f\x63\x61rtesianConfig\x18\x13 \x01(\x0b\x32\x17.robotc.CartesianConfig\x12\x1b\n\x13\x65xtra_robotDIOInNum\x18\x14 \x01(\x05\x12\x1c\n\x14\x65xtra_robotDIOOutNum\x18\x15 \x01(\x05\x12+\n\x16\x65xtra_robotAIOInConfig\x18\x16 \x03(\x0b\x32\x0b.robotc.AIO\x12,\n\x17\x65xtra_robotAIOOutConfig\x18\x17 \x03(\x0b\x32\x0b.robotc.AIO\"\x15\n\x04Zero\x12\r\n\x05zeros\x18\x01 \x03(\x01\"\xb1\x03\n\x06Notice\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.robotc.Notice.NoticeType\x12#\n\x02id\x18\x02 \x01(\x0e\x32\x17.robotc.Notice.NoticeId\x12\r\n\x05value\x18\x03 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x04 \x01(\x05\x12\x0b\n\x03lol\x18\x05 \x03(\x01\x12\r\n\x05\x63ount\x18\x06 \x01(\x05\"C\n\nNoticeType\x12\x10\n\x0cNOTICE_STATE\x10\x00\x12\x10\n\x0cNOTICE_ERROR\x10\x01\x12\x11\n\rNOTICE_BUTTON\x10\x02\"\xda\x01\n\x08NoticeId\x12\x1f\n\x1bNOTICE_ID_STATE_ROBOT_STATE\x10\x00\x12\x1a\n\x16NOTICE_ID_STATE_E_STOP\x10\x01\x12\x1f\n\x1bNOTICE_ID_STATE_DATA_UPDATE\x10\x02\x12\x13\n\x0fNOTICE_ID_ERROR\x10\x03\x12\x1d\n\x19NOTICE_ID_BUTTON_SHOULDER\x10\x04\x12\x1d\n\x19NOTICE_ID_BUTTON_FLANGE_1\x10\x05\x12\x1d\n\x19NOTICE_ID_BUTTON_FLANGE_2\x10\x06\"-\n\x0cNotification\x12\x1d\n\x05items\x18\x01 \x03(\x0b\x32\x0e.robotc.Notice\"Y\n\x06\x44river\x12\"\n\x08hardware\x18\x01 \x01(\x0b\x32\x10.robotc.Hardware\x12+\n\x0c\x63urPartition\x18\x02 \x01(\x0e\x32\x15.robotc.BootPartition\"\x8b\x01\n\nDriverInfo\x12\x1e\n\x06\x66lange\x18\x01 \x01(\x0b\x32\x0e.robotc.Driver\x12\x1b\n\x03led\x18\x02 \x01(\x0b\x32\x0e.robotc.Driver\x12\x1e\n\x06joints\x18\x03 \x03(\x0b\x32\x0e.robotc.Driver\x12 \n\x08\x63omboard\x18\x04 \x01(\x0b\x32\x0e.robotc.Driver\"5\n\x07OTAFile\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x0b\n\x03md5\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"d\n\x06OTACmd\x12*\n\x0c\x62ootloaderId\x18\x01 \x01(\x0e\x32\x14.robotc.BootloaderId\x12.\n\x0ftargetPartition\x18\x02 \x01(\x0e\x32\x15.robotc.BootPartition\"E\n\x07OTAData\x12\x1b\n\x03\x63md\x18\x01 \x01(\x0b\x32\x0e.robotc.OTACmd\x12\x1d\n\x04\x66ile\x18\x02 \x01(\x0b\x32\x0f.robotc.OTAFile\"H\n\tOTAJoints\x12\x1c\n\x04\x63mds\x18\x01 \x03(\x0b\x32\x0e.robotc.OTACmd\x12\x1d\n\x04\x66ile\x18\x02 \x01(\x0b\x32\x0f.robotc.OTAFile\"Q\n\x08OTADatas\x12!\n\x06joints\x18\x01 \x01(\x0b\x32\x11.robotc.OTAJoints\x12\"\n\tnotJoints\x18\x02 \x03(\x0b\x32\x0f.robotc.OTAData\"\x96\x01\n\tOTAResult\x12*\n\x0c\x62ootloaderId\x18\x01 \x01(\x0e\x32\x14.robotc.BootloaderId\x12\x0c\n\x04step\x18\x02 \x01(\x05\x12\x14\n\x0cstepProgress\x18\x03 \x01(\x05\x12\x0f\n\x07version\x18\x04 \x01(\t\x12(\n\tpartition\x18\x05 \x01(\x0e\x32\x15.robotc.BootPartition\"0\n\nOTAResults\x12\"\n\x07results\x18\x01 \x03(\x0b\x32\x11.robotc.OTAResult\"N\n\x0e\x43urrentVoltage\x12\r\n\x05power\x18\x01 \x01(\x01\x12\x0c\n\x04\x66lan\x18\x02 \x01(\x01\x12\r\n\x05joint\x18\x03 \x03(\x01\x12\x10\n\x08io_power\x18\x04 \x01(\x01\"t\n\x0fJointServoParam\x12\r\n\x05index\x18\x01 \x01(\r\x12\x13\n\x0bposition_kp\x18\x02 \x01(\x01\x12\x10\n\x08speed_kp\x18\x03 \x01(\x01\x12\x10\n\x08speed_it\x18\x04 \x01(\x01\x12\x19\n\x11torque_cmd_filter\x18\x05 \x01(\x01\";\n\x10JointServoParams\x12\'\n\x06joints\x18\x01 \x03(\x0b\x32\x17.robotc.JointServoParam\"\x18\n\x0b\x44\x65\x62ugParams\x12\t\n\x01\x64\x18\x01 \x03(\x01\"X\n\x0c\x46ixDHRequest\x12\x13\n\x0b\x64\x65lta_theta\x18\x01 \x03(\x01\x12\x12\n\nplus_theta\x18\x02 \x01(\x08\x12\x0f\n\x07\x64\x65lta_l\x18\x03 \x03(\x01\x12\x0e\n\x06plus_l\x18\x04 \x01(\x08\"$\n\tDHRequest\x12\x17\n\x0fget_theoretical\x18\x01 \x01(\x08\"9\n\x03\x44Ht\x12\t\n\x01\x64\x18\x01 \x01(\x01\x12\t\n\x01\x61\x18\x02 \x01(\x01\x12\r\n\x05\x61lpha\x18\x03 \x01(\x01\x12\r\n\x05theta\x18\x04 \x01(\x01\"\'\n\x08\x44HParams\x12\x1b\n\x06params\x18\x01 \x03(\x0b\x32\x0b.robotc.DHt\"c\n\x0b\x46ixDHResult\x12\x1b\n\x06origin\x18\x01 \x03(\x0b\x32\x0b.robotc.DHt\x12\x1b\n\x06\x62\x65\x66ore\x18\x02 \x03(\x0b\x32\x0b.robotc.DHt\x12\x1a\n\x05\x61\x66ter\x18\x03 \x03(\x0b\x32\x0b.robotc.DHt\"&\n\x06Option\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\"\x99\x03\n\x08LuaEvent\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.robotc.LuaEvent.Type\x12\x0e\n\x06\x63md_id\x18\x02 \x01(\x05\x12,\n\tcmd_state\x18\x03 \x01(\x0e\x32\x19.robotc.LuaEvent.CmdState\x12\x10\n\x08\x65\x63ho_key\x18\x04 \x01(\t\x12\r\n\x05index\x18\x08 \x01(\x05\x12#\n\tlua_state\x18\x05 \x01(\x0e\x32\x10.robotc.LuaState\x12\x11\n\tsignal_id\x18\x06 \x01(\x05\x12\x14\n\x0csignal_value\x18\x07 \x01(\x01\x12\x1f\n\x07options\x18\t \x03(\x0b\x32\x0e.robotc.Option\"^\n\x04Type\x12\x08\n\x04\x45\x43HO\x10\x00\x12\x07\n\x03LUA\x10\x01\x12\n\n\x06SIGNAL\x10\x02\x12\x08\n\x04LOOP\x10\x03\x12\t\n\x05\x41LERT\x10\x04\x12\x0b\n\x07\x43ONFIRM\x10\x05\x12\t\n\x05INPUT\x10\x06\x12\n\n\x06SELECT\x10\x07\":\n\x08\x43mdState\x12\x08\n\x04INIT\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\"\x1d\n\x0c\x43onfirmInput\x12\r\n\x05input\x18\x01 \x01(\t\"A\n\x07PoseRes\x12\x18\n\x04\x63\x61rt\x18\x01 \x01(\x0b\x32\n.robotc.PR\x12\x1c\n\x05joint\x18\x02 \x01(\x0b\x32\r.robotc.JPose\"&\n\tModbusDio\x12\x0b\n\x03pin\x18\x01 \x01(\x05\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\x05\"?\n\x0eModbusDioGroup\x12\x1f\n\x04pins\x18\x01 \x03(\x0b\x32\x11.robotc.ModbusDio\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\x05\"4\n\tModbusAio\x12\x0b\n\x03pin\x18\x01 \x01(\x05\x12\x0c\n\x04mode\x18\x02 \x01(\x05\x12\x0c\n\x04\x61\x64\x64r\x18\x03 \x01(\x05\"$\n\x08\x41IORange\x12\x0b\n\x03min\x18\x01 \x01(\x01\x12\x0b\n\x03max\x18\x02 \x01(\x01\"A\n\x05Range\x12\x1b\n\x01V\x18\x01 \x01(\x0b\x32\x10.robotc.AIORange\x12\x1b\n\x01\x41\x18\x02 \x01(\x0b\x32\x10.robotc.AIORange\"z\n\x0eModbusAioGroup\x12\x1f\n\x04pins\x18\x01 \x03(\x0b\x32\x11.robotc.ModbusAio\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\x05\x12\r\n\x05isLsb\x18\x03 \x01(\x05\x12\x1c\n\x05range\x18\x04 \x01(\x0b\x32\r.robotc.Range\x12\x0c\n\x04size\x18\x05 \x01(\x05\"\xa9\x01\n\x17ModbusExternalIOMapping\x12\"\n\x02\x64i\x18\x01 \x01(\x0b\x32\x16.robotc.ModbusDioGroup\x12\"\n\x02\x64o\x18\x02 \x01(\x0b\x32\x16.robotc.ModbusDioGroup\x12\"\n\x02\x61i\x18\x03 \x01(\x0b\x32\x16.robotc.ModbusAioGroup\x12\"\n\x02\x61o\x18\x04 \x01(\x0b\x32\x16.robotc.ModbusAioGroup\"\xb0\x01\n\x10ModbusExternalIO\x12\n\n\x02id\x18\x01 \x01(\x05\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\x12\x0f\n\x07slaveId\x18\x05 \x01(\x05\x12\x13\n\x0b\x63mdHoldTime\x18\x06 \x01(\x05\x12\x0f\n\x07version\x18\x07 \x01(\x05\x12.\n\x05ioMap\x18\x08 \x01(\x0b\x32\x1f.robotc.ModbusExternalIOMapping\":\n\x11ModbusExternalIOs\x12%\n\x03ios\x18\x01 \x03(\x0b\x32\x18.robotc.ModbusExternalIO\"\x93\x02\n\x11RecordPVATRequest\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".robotc.RecordPVATRequest.PVATType\x12\x10\n\x08\x64uration\x18\x02 \x01(\x01\x12\x34\n\x08vZeroGap\x18\x03 \x01(\x0b\x32\".robotc.RecordPVATRequest.VZeroGap\x12\x17\n\x0fuse_duration_ts\x18\x04 \x01(\x08\x12\x11\n\tsave_file\x18\x05 \x01(\x08\x1a\x31\n\x08VZeroGap\x12\x11\n\tthreshold\x18\x01 \x01(\x01\x12\x12\n\nremove_gap\x18\x02 \x01(\x08\"%\n\x08PVATType\x12\x06\n\x02PT\x10\x00\x12\x07\n\x03PVT\x10\x01\x12\x08\n\x04PVAT\x10\x02\"Z\n\x12RecordPVATResponse\x12\t\n\x01p\x18\x01 \x03(\x01\x12\t\n\x01v\x18\x02 \x03(\x01\x12\x0b\n\x03\x61\x63\x63\x18\x03 \x03(\x01\x12\t\n\x01t\x18\x04 \x01(\x01\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x08\x12\t\n\x01\x66\x18\x06 \x01(\t*\xa7\x01\n\x0c\x42ootloaderId\x12\x0e\n\nALL_JOINTS\x10\x00\x12\x0b\n\x07JOINT_1\x10\x01\x12\x0b\n\x07JOINT_2\x10\x02\x12\x0b\n\x07JOINT_3\x10\x03\x12\x0b\n\x07JOINT_4\x10\x04\x12\x0b\n\x07JOINT_5\x10\x05\x12\x0b\n\x07JOINT_6\x10\x06\x12\x0b\n\x07JOINT_7\x10\x07\x12\n\n\x06\x46LANGE\x10\x08\x12\x08\n\x04\x43LAW\x10\t\x12\x08\n\x04LAMP\x10\n\x12\x0c\n\x08\x43OMBOARD\x10\x0e*6\n\rBootPartition\x12\x05\n\x01\x41\x10\x00\x12\x05\n\x01\x42\x10\x01\x12\x05\n\x01\x43\x10\x02\x12\x10\n\x0cPART_UNKNOWN\x10\x03\x32\xab\x1b\n\x16RobotPrivateController\x12/\n\x04Init\x12\x15.robotc.Configuration\x1a\x10.robotc.Response\x12\x39\n\x0cGetRobotInfo\x12\x16.google.protobuf.Empty\x1a\x11.robotc.RobotInfo\x12\x41\n\x13SetInstallDirection\x12\x18.robotc.InstallDirection\x1a\x10.robotc.Response\x12\x43\n\x14SetCollisionDetector\x12\x19.robotc.CollisionDetector\x1a\x10.robotc.Response\x12\x38\n\x0eSetJointConfig\x12\x14.robotc.JointConfigs\x1a\x10.robotc.Response\x12?\n\x12SetCartesianConfig\x12\x17.robotc.CartesianConfig\x1a\x10.robotc.Response\x12\x32\n\tEnableDDS\x12\x13.robotc.TrueOrFalse\x1a\x10.robotc.Response\x12G\n\x16SetCollisionTorqueDiff\x12\x1b.robotc.CollisionTorqueDiff\x1a\x10.robotc.Response\x12\x46\n\x14RegisterNotification\x12\x16.google.protobuf.Empty\x1a\x14.robotc.Notification0\x01\x12=\n\x0fRobotDriverInfo\x12\x16.google.protobuf.Empty\x1a\x12.robotc.DriverInfo\x12\x30\n\x08RobotOTA\x12\x0f.robotc.OTAData\x1a\x11.robotc.OTAResult0\x01\x12\x36\n\x12SwitchOtaPartition\x12\x0e.robotc.OTACmd\x1a\x10.robotc.Response\x12\x37\n\rRobotOTABatch\x12\x10.robotc.OTADatas\x1a\x12.robotc.OTAResults0\x01\x12\x31\n\x05Reset\x12\x16.google.protobuf.Empty\x1a\x10.robotc.Response\x12*\n\x08InitZero\x12\x0c.robotc.Zero\x1a\x10.robotc.Response\x12\x33\n\x07SetZero\x12\x16.google.protobuf.Empty\x1a\x10.robotc.Response\x12<\n\nGetVoltage\x12\x16.google.protobuf.Empty\x1a\x16.robotc.CurrentVoltage\x12\x42\n\rSetServoParam\x12\x17.robotc.JointServoParam\x1a\x18.robotc.JointServoParams\x12\x42\n\x0eGetServoParams\x12\x16.google.protobuf.Empty\x1a\x18.robotc.JointServoParams\x12:\n\x0eSetDebugParams\x12\x13.robotc.DebugParams\x1a\x13.robotc.DebugParams\x12\x38\n\x0b\x46ixDHParams\x12\x14.robotc.FixDHRequest\x1a\x13.robotc.FixDHResult\x12\x32\n\x0bSetLEDStyle\x12\x10.robotc.LEDStyle\x1a\x11.robotc.LEDStyles\x12\x39\n\x0cGetLEDStyles\x12\x16.google.protobuf.Empty\x1a\x11.robotc.LEDStyles\x12>\n\x10RegisterLuaEvent\x12\x16.google.protobuf.Empty\x1a\x10.robotc.LuaEvent0\x01\x12\x39\n\x0f\x43onfirmCallback\x12\x14.robotc.ConfirmInput\x1a\x10.robotc.Response\x12\x36\n\x0bGetLastPose\x12\x16.google.protobuf.Empty\x1a\x0f.robotc.PoseRes\x12\x42\n\x13SetModbusExternalIO\x12\x19.robotc.ModbusExternalIOs\x1a\x10.robotc.Response\x12\x39\n\x0fSetButtonConfig\x12\x14.robotc.ButtonConfig\x1a\x10.robotc.Response\x12\x35\n\x0cSetBreakACup\x12\x13.robotc.TrueOrFalse\x1a\x10.robotc.Response\x12\x45\n\nRecordPVAT\x12\x19.robotc.RecordPVATRequest\x1a\x1a.robotc.RecordPVATResponse0\x01\x12:\n\x0eStopRecordPVAT\x12\x16.google.protobuf.Empty\x1a\x10.robotc.Response\x12<\n\x10UpgradeVoiceFile\x12\x11.robotc.VoiceFile\x1a\x13.robotc.VoiceResult0\x01\x12\x32\n\x0bGetDHParams\x12\x11.robotc.DHRequest\x1a\x10.robotc.DHParams\x12\x31\n\x0bSetDHParams\x12\x10.robotc.DHParams\x1a\x10.robotc.DHParams\x12H\n\x14WriteExtraServoParam\x12\x17.robotc.ExtraServoParam\x1a\x17.robotc.ExtraServoParam\x12G\n\x13ReadExtraServoParam\x12\x17.robotc.ExtraServoParam\x1a\x17.robotc.ExtraServoParam\x12J\n\x15WriteExtraServoParams\x12\x17.robotc.ExtraServoParam\x1a\x18.robotc.ExtraServoParams\x12H\n\x14ReadExtraServoParams\x12\x16.google.protobuf.Empty\x1a\x18.robotc.ExtraServoParams\x12I\n\x15ResetExtraServoParams\x12\x16.google.protobuf.Empty\x1a\x18.robotc.ExtraServoParams\x12\x42\n\x12WriteJointBacklash\x12\x15.robotc.JointBacklash\x1a\x15.robotc.JointBacklash\x12\x41\n\x11ReadJointBacklash\x12\x15.robotc.JointBacklash\x1a\x15.robotc.JointBacklash\x12\x46\n\x14WriteJointBacklashes\x12\x15.robotc.JointBacklash\x1a\x17.robotc.JointBacklashes\x12\x46\n\x13ReadJointBacklashes\x12\x16.google.protobuf.Empty\x1a\x17.robotc.JointBacklashes\x12G\n\x14ResetJointBacklashes\x12\x16.google.protobuf.Empty\x1a\x17.robotc.JointBacklashes\x12X\n\x1aWriteEnableJointBacklashes\x12\x1b.robotc.EnableJointBacklash\x1a\x1d.robotc.EnableJointBacklashes\x12R\n\x19ReadEnableJointBacklashes\x12\x16.google.protobuf.Empty\x1a\x1d.robotc.EnableJointBacklashes\x12S\n\x1aResetEnableJointBacklashes\x12\x16.google.protobuf.Empty\x1a\x1d.robotc.EnableJointBacklashes\x12Q\n\x17WriteJointBacklashParam\x12\x1a.robotc.JointBacklashParam\x1a\x1a.robotc.JointBacklashParam\x12P\n\x16ReadJointBacklashParam\x12\x1a.robotc.JointBacklashParam\x1a\x1a.robotc.JointBacklashParam\x12S\n\x18WriteJointBacklashParams\x12\x1a.robotc.JointBacklashParam\x1a\x1b.robotc.JointBacklashParams\x12N\n\x17ReadJointBacklashParams\x12\x16.google.protobuf.Empty\x1a\x1b.robotc.JointBacklashParams\x12O\n\x18ResetJointBacklashParams\x12\x16.google.protobuf.Empty\x1a\x1b.robotc.JointBacklashParams\x12\x39\n\x10\x45nableJointLimit\x12\x13.robotc.TrueOrFalse\x1a\x10.robotc.Responseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,messages__pb2.DESCRIPTOR,])

_BOOTLOADERID = _descriptor.EnumDescriptor(
  name='BootloaderId',
  full_name='robotc.BootloaderId',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL_JOINTS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOINT_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOINT_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOINT_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOINT_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOINT_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOINT_6', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOINT_7', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLANGE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLAW', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAMP', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMBOARD', index=11, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6165,
  serialized_end=6332,
)
_sym_db.RegisterEnumDescriptor(_BOOTLOADERID)

BootloaderId = enum_type_wrapper.EnumTypeWrapper(_BOOTLOADERID)
_BOOTPARTITION = _descriptor.EnumDescriptor(
  name='BootPartition',
  full_name='robotc.BootPartition',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='A', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='B', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='C', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PART_UNKNOWN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6334,
  serialized_end=6388,
)
_sym_db.RegisterEnumDescriptor(_BOOTPARTITION)

BootPartition = enum_type_wrapper.EnumTypeWrapper(_BOOTPARTITION)
ALL_JOINTS = 0
JOINT_1 = 1
JOINT_2 = 2
JOINT_3 = 3
JOINT_4 = 4
JOINT_5 = 5
JOINT_6 = 6
JOINT_7 = 7
FLANGE = 8
CLAW = 9
LAMP = 10
COMBOARD = 14
A = 0
B = 1
C = 2
PART_UNKNOWN = 3


_NOTICE_NOTICETYPE = _descriptor.EnumDescriptor(
  name='NoticeType',
  full_name='robotc.Notice.NoticeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOTICE_STATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOTICE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOTICE_BUTTON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2673,
  serialized_end=2740,
)
_sym_db.RegisterEnumDescriptor(_NOTICE_NOTICETYPE)

_NOTICE_NOTICEID = _descriptor.EnumDescriptor(
  name='NoticeId',
  full_name='robotc.Notice.NoticeId',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOTICE_ID_STATE_ROBOT_STATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOTICE_ID_STATE_E_STOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOTICE_ID_STATE_DATA_UPDATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOTICE_ID_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOTICE_ID_BUTTON_SHOULDER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOTICE_ID_BUTTON_FLANGE_1', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOTICE_ID_BUTTON_FLANGE_2', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2743,
  serialized_end=2961,
)
_sym_db.RegisterEnumDescriptor(_NOTICE_NOTICEID)

_LUAEVENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='robotc.LuaEvent.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ECHO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LUA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIGNAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOOP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALERT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONFIRM', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INPUT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SELECT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4741,
  serialized_end=4835,
)
_sym_db.RegisterEnumDescriptor(_LUAEVENT_TYPE)

_LUAEVENT_CMDSTATE = _descriptor.EnumDescriptor(
  name='CmdState',
  full_name='robotc.LuaEvent.CmdState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INIT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4837,
  serialized_end=4895,
)
_sym_db.RegisterEnumDescriptor(_LUAEVENT_CMDSTATE)

_RECORDPVATREQUEST_PVATTYPE = _descriptor.EnumDescriptor(
  name='PVATType',
  full_name='robotc.RecordPVATRequest.PVATType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PVT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PVAT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6033,
  serialized_end=6070,
)
_sym_db.RegisterEnumDescriptor(_RECORDPVATREQUEST_PVATTYPE)


_ENABLEJOINTBACKLASH = _descriptor.Descriptor(
  name='EnableJointBacklash',
  full_name='robotc.EnableJointBacklash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint', full_name='robotc.EnableJointBacklash.joint', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='robotc.EnableJointBacklash.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=133,
)


_ENABLEJOINTBACKLASHES = _descriptor.Descriptor(
  name='EnableJointBacklashes',
  full_name='robotc.EnableJointBacklashes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.EnableJointBacklashes.joints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=203,
)


_EXTRASERVOPARAM = _descriptor.Descriptor(
  name='ExtraServoParam',
  full_name='robotc.ExtraServoParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint', full_name='robotc.ExtraServoParam.joint', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_position_kp', full_name='robotc.ExtraServoParam.acc_position_kp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_speed_kp', full_name='robotc.ExtraServoParam.acc_speed_kp', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_speed_it', full_name='robotc.ExtraServoParam.acc_speed_it', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_position_kp', full_name='robotc.ExtraServoParam.uni_position_kp', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_speed_kp', full_name='robotc.ExtraServoParam.uni_speed_kp', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_speed_it', full_name='robotc.ExtraServoParam.uni_speed_it', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dec_position_kp', full_name='robotc.ExtraServoParam.dec_position_kp', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dec_speed_kp', full_name='robotc.ExtraServoParam.dec_speed_kp', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dec_speed_it', full_name='robotc.ExtraServoParam.dec_speed_it', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=445,
)


_EXTRASERVOPARAMS = _descriptor.Descriptor(
  name='ExtraServoParams',
  full_name='robotc.ExtraServoParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.ExtraServoParams.joints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=506,
)


_JOINTBACKLASH = _descriptor.Descriptor(
  name='JointBacklash',
  full_name='robotc.JointBacklash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint', full_name='robotc.JointBacklash.joint', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k', full_name='robotc.JointBacklash.k', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iq', full_name='robotc.JointBacklash.iq', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iq_final', full_name='robotc.JointBacklash.iq_final', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iq_count', full_name='robotc.JointBacklash.iq_count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=597,
)


_JOINTBACKLASHES = _descriptor.Descriptor(
  name='JointBacklashes',
  full_name='robotc.JointBacklashes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.JointBacklashes.joints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=655,
)


_JOINTBACKLASHPARAM = _descriptor.Descriptor(
  name='JointBacklashParam',
  full_name='robotc.JointBacklashParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint', full_name='robotc.JointBacklashParam.joint', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoder_data_offset', full_name='robotc.JointBacklashParam.encoder_data_offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on', full_name='robotc.JointBacklashParam.on', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='over', full_name='robotc.JointBacklashParam.over', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leave', full_name='robotc.JointBacklashParam.leave', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='robotc.JointBacklashParam.max', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=775,
)


_JOINTBACKLASHPARAMS = _descriptor.Descriptor(
  name='JointBacklashParams',
  full_name='robotc.JointBacklashParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.JointBacklashParams.joints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=842,
)


_VOICEFILE = _descriptor.Descriptor(
  name='VoiceFile',
  full_name='robotc.VoiceFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.VoiceFile.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file', full_name='robotc.VoiceFile.file', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='md5', full_name='robotc.VoiceFile.md5', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=894,
)


_VOICERESULT = _descriptor.Descriptor(
  name='VoiceResult',
  full_name='robotc.VoiceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.VoiceResult.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='robotc.VoiceResult.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stepProgress', full_name='robotc.VoiceResult.stepProgress', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=957,
)


_TRUEORFALSE = _descriptor.Descriptor(
  name='TrueOrFalse',
  full_name='robotc.TrueOrFalse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='robotc.TrueOrFalse.val', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=985,
)


_INSTALLDIRECTION = _descriptor.Descriptor(
  name='InstallDirection',
  full_name='robotc.InstallDirection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction', full_name='robotc.InstallDirection.direction', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1024,
)


_JOINTCONFIG = _descriptor.Descriptor(
  name='JointConfig',
  full_name='robotc.JointConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maxAngle', full_name='robotc.JointConfig.maxAngle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minAngle', full_name='robotc.JointConfig.minAngle', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxV', full_name='robotc.JointConfig.maxV', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxAcc', full_name='robotc.JointConfig.maxAcc', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1105,
)


_JOINTCONFIGS = _descriptor.Descriptor(
  name='JointConfigs',
  full_name='robotc.JointConfigs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configs', full_name='robotc.JointConfigs.configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1159,
)


_CARTESIANCONFIG = _descriptor.Descriptor(
  name='CartesianConfig',
  full_name='robotc.CartesianConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maxV', full_name='robotc.CartesianConfig.maxV', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxAcc', full_name='robotc.CartesianConfig.maxAcc', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1208,
)


_SAFETYPLAT = _descriptor.Descriptor(
  name='SafetyPlat',
  full_name='robotc.SafetyPlat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='robotc.SafetyPlat.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1258,
)


_SAFETYPLATS = _descriptor.Descriptor(
  name='SafetyPlats',
  full_name='robotc.SafetyPlats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plats', full_name='robotc.SafetyPlats.plats', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1308,
)


_COLLISIONTORQUEDIFF = _descriptor.Descriptor(
  name='CollisionTorqueDiff',
  full_name='robotc.CollisionTorqueDiff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='diffs', full_name='robotc.CollisionTorqueDiff.diffs', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1310,
  serialized_end=1346,
)


_COLLISIONDETECTOR = _descriptor.Descriptor(
  name='CollisionDetector',
  full_name='robotc.CollisionDetector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='robotc.CollisionDetector.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='robotc.CollisionDetector.action', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pauseTime', full_name='robotc.CollisionDetector.pauseTime', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensitivity', full_name='robotc.CollisionDetector.sensitivity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1348,
  serialized_end=1439,
)


_LEDSTYLE = _descriptor.Descriptor(
  name='LEDStyle',
  full_name='robotc.LEDStyle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='robotc.LEDStyle.mode', index=0,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='robotc.LEDStyle.speed', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='robotc.LEDStyle.color', index=2,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice', full_name='robotc.LEDStyle.voice', index=3,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='robotc.LEDStyle.volume', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robotMode', full_name='robotc.LEDStyle.robotMode', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1441,
  serialized_end=1545,
)


_LEDSTYLES = _descriptor.Descriptor(
  name='LEDStyles',
  full_name='robotc.LEDStyles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='styles', full_name='robotc.LEDStyles.styles', index=0,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1547,
  serialized_end=1592,
)


_BUTTONCONFIG = _descriptor.Descriptor(
  name='ButtonConfig',
  full_name='robotc.ButtonConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='btn_flan_1', full_name='robotc.ButtonConfig.btn_flan_1', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='btn_flan_2', full_name='robotc.ButtonConfig.btn_flan_2', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='btn_shoulder_0', full_name='robotc.ButtonConfig.btn_shoulder_0', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1594,
  serialized_end=1672,
)


_CONFIGURATION = _descriptor.Descriptor(
  name='Configuration',
  full_name='robotc.Configuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='installDirection', full_name='robotc.Configuration.installDirection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collisionDetector', full_name='robotc.Configuration.collisionDetector', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jointConfigs', full_name='robotc.Configuration.jointConfigs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safetyPlats', full_name='robotc.Configuration.safetyPlats', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp', full_name='robotc.Configuration.tcp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='robotc.Configuration.payload', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enableDDS', full_name='robotc.Configuration.enableDDS', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collisionTorqueDiff', full_name='robotc.Configuration.collisionTorqueDiff', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robotDIOInNum', full_name='robotc.Configuration.robotDIOInNum', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robotDIOOutNum', full_name='robotc.Configuration.robotDIOOutNum', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robotAIOInConfig', full_name='robotc.Configuration.robotAIOInConfig', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robotAIOOutConfig', full_name='robotc.Configuration.robotAIOOutConfig', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcpDIOInNum', full_name='robotc.Configuration.tcpDIOInNum', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcpDIOOutNum', full_name='robotc.Configuration.tcpDIOOutNum', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zeros', full_name='robotc.Configuration.zeros', index=14,
      number=15, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='styles', full_name='robotc.Configuration.styles', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='break_a_cup', full_name='robotc.Configuration.break_a_cup', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button_config', full_name='robotc.Configuration.button_config', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cartesianConfig', full_name='robotc.Configuration.cartesianConfig', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_robotDIOInNum', full_name='robotc.Configuration.extra_robotDIOInNum', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_robotDIOOutNum', full_name='robotc.Configuration.extra_robotDIOOutNum', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_robotAIOInConfig', full_name='robotc.Configuration.extra_robotAIOInConfig', index=21,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_robotAIOOutConfig', full_name='robotc.Configuration.extra_robotAIOOutConfig', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1675,
  serialized_end=2502,
)


_ZERO = _descriptor.Descriptor(
  name='Zero',
  full_name='robotc.Zero',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zeros', full_name='robotc.Zero.zeros', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2504,
  serialized_end=2525,
)


_NOTICE = _descriptor.Descriptor(
  name='Notice',
  full_name='robotc.Notice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='robotc.Notice.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.Notice.id', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.Notice.value', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='robotc.Notice.code', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lol', full_name='robotc.Notice.lol', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='robotc.Notice.count', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NOTICE_NOTICETYPE,
    _NOTICE_NOTICEID,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2528,
  serialized_end=2961,
)


_NOTIFICATION = _descriptor.Descriptor(
  name='Notification',
  full_name='robotc.Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='robotc.Notification.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2963,
  serialized_end=3008,
)


_DRIVER = _descriptor.Descriptor(
  name='Driver',
  full_name='robotc.Driver',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hardware', full_name='robotc.Driver.hardware', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curPartition', full_name='robotc.Driver.curPartition', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3010,
  serialized_end=3099,
)


_DRIVERINFO = _descriptor.Descriptor(
  name='DriverInfo',
  full_name='robotc.DriverInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flange', full_name='robotc.DriverInfo.flange', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led', full_name='robotc.DriverInfo.led', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.DriverInfo.joints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comboard', full_name='robotc.DriverInfo.comboard', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3102,
  serialized_end=3241,
)


_OTAFILE = _descriptor.Descriptor(
  name='OTAFile',
  full_name='robotc.OTAFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='robotc.OTAFile.file', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='md5', full_name='robotc.OTAFile.md5', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='robotc.OTAFile.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3243,
  serialized_end=3296,
)


_OTACMD = _descriptor.Descriptor(
  name='OTACmd',
  full_name='robotc.OTACmd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bootloaderId', full_name='robotc.OTACmd.bootloaderId', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPartition', full_name='robotc.OTACmd.targetPartition', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3298,
  serialized_end=3398,
)


_OTADATA = _descriptor.Descriptor(
  name='OTAData',
  full_name='robotc.OTAData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='robotc.OTAData.cmd', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file', full_name='robotc.OTAData.file', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3400,
  serialized_end=3469,
)


_OTAJOINTS = _descriptor.Descriptor(
  name='OTAJoints',
  full_name='robotc.OTAJoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmds', full_name='robotc.OTAJoints.cmds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file', full_name='robotc.OTAJoints.file', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3471,
  serialized_end=3543,
)


_OTADATAS = _descriptor.Descriptor(
  name='OTADatas',
  full_name='robotc.OTADatas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.OTADatas.joints', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notJoints', full_name='robotc.OTADatas.notJoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3545,
  serialized_end=3626,
)


_OTARESULT = _descriptor.Descriptor(
  name='OTAResult',
  full_name='robotc.OTAResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bootloaderId', full_name='robotc.OTAResult.bootloaderId', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='robotc.OTAResult.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stepProgress', full_name='robotc.OTAResult.stepProgress', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='robotc.OTAResult.version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition', full_name='robotc.OTAResult.partition', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3629,
  serialized_end=3779,
)


_OTARESULTS = _descriptor.Descriptor(
  name='OTAResults',
  full_name='robotc.OTAResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='robotc.OTAResults.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3781,
  serialized_end=3829,
)


_CURRENTVOLTAGE = _descriptor.Descriptor(
  name='CurrentVoltage',
  full_name='robotc.CurrentVoltage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='power', full_name='robotc.CurrentVoltage.power', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flan', full_name='robotc.CurrentVoltage.flan', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joint', full_name='robotc.CurrentVoltage.joint', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_power', full_name='robotc.CurrentVoltage.io_power', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3831,
  serialized_end=3909,
)


_JOINTSERVOPARAM = _descriptor.Descriptor(
  name='JointServoParam',
  full_name='robotc.JointServoParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='robotc.JointServoParam.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_kp', full_name='robotc.JointServoParam.position_kp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_kp', full_name='robotc.JointServoParam.speed_kp', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_it', full_name='robotc.JointServoParam.speed_it', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque_cmd_filter', full_name='robotc.JointServoParam.torque_cmd_filter', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3911,
  serialized_end=4027,
)


_JOINTSERVOPARAMS = _descriptor.Descriptor(
  name='JointServoParams',
  full_name='robotc.JointServoParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.JointServoParams.joints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4029,
  serialized_end=4088,
)


_DEBUGPARAMS = _descriptor.Descriptor(
  name='DebugParams',
  full_name='robotc.DebugParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='d', full_name='robotc.DebugParams.d', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4090,
  serialized_end=4114,
)


_FIXDHREQUEST = _descriptor.Descriptor(
  name='FixDHRequest',
  full_name='robotc.FixDHRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delta_theta', full_name='robotc.FixDHRequest.delta_theta', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plus_theta', full_name='robotc.FixDHRequest.plus_theta', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_l', full_name='robotc.FixDHRequest.delta_l', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plus_l', full_name='robotc.FixDHRequest.plus_l', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4116,
  serialized_end=4204,
)


_DHREQUEST = _descriptor.Descriptor(
  name='DHRequest',
  full_name='robotc.DHRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_theoretical', full_name='robotc.DHRequest.get_theoretical', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4206,
  serialized_end=4242,
)


_DHT = _descriptor.Descriptor(
  name='DHt',
  full_name='robotc.DHt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='d', full_name='robotc.DHt.d', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='robotc.DHt.a', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alpha', full_name='robotc.DHt.alpha', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='robotc.DHt.theta', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4244,
  serialized_end=4301,
)


_DHPARAMS = _descriptor.Descriptor(
  name='DHParams',
  full_name='robotc.DHParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='robotc.DHParams.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4303,
  serialized_end=4342,
)


_FIXDHRESULT = _descriptor.Descriptor(
  name='FixDHResult',
  full_name='robotc.FixDHResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='robotc.FixDHResult.origin', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='before', full_name='robotc.FixDHResult.before', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='after', full_name='robotc.FixDHResult.after', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4344,
  serialized_end=4443,
)


_OPTION = _descriptor.Descriptor(
  name='Option',
  full_name='robotc.Option',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.Option.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='robotc.Option.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4445,
  serialized_end=4483,
)


_LUAEVENT = _descriptor.Descriptor(
  name='LuaEvent',
  full_name='robotc.LuaEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='robotc.LuaEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd_id', full_name='robotc.LuaEvent.cmd_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd_state', full_name='robotc.LuaEvent.cmd_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='echo_key', full_name='robotc.LuaEvent.echo_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='robotc.LuaEvent.index', index=4,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lua_state', full_name='robotc.LuaEvent.lua_state', index=5,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_id', full_name='robotc.LuaEvent.signal_id', index=6,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_value', full_name='robotc.LuaEvent.signal_value', index=7,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='robotc.LuaEvent.options', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LUAEVENT_TYPE,
    _LUAEVENT_CMDSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4486,
  serialized_end=4895,
)


_CONFIRMINPUT = _descriptor.Descriptor(
  name='ConfirmInput',
  full_name='robotc.ConfirmInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='robotc.ConfirmInput.input', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4897,
  serialized_end=4926,
)


_POSERES = _descriptor.Descriptor(
  name='PoseRes',
  full_name='robotc.PoseRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cart', full_name='robotc.PoseRes.cart', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joint', full_name='robotc.PoseRes.joint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4928,
  serialized_end=4993,
)


_MODBUSDIO = _descriptor.Descriptor(
  name='ModbusDio',
  full_name='robotc.ModbusDio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.ModbusDio.pin', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addr', full_name='robotc.ModbusDio.addr', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4995,
  serialized_end=5033,
)


_MODBUSDIOGROUP = _descriptor.Descriptor(
  name='ModbusDioGroup',
  full_name='robotc.ModbusDioGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pins', full_name='robotc.ModbusDioGroup.pins', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addr', full_name='robotc.ModbusDioGroup.addr', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5035,
  serialized_end=5098,
)


_MODBUSAIO = _descriptor.Descriptor(
  name='ModbusAio',
  full_name='robotc.ModbusAio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.ModbusAio.pin', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='robotc.ModbusAio.mode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addr', full_name='robotc.ModbusAio.addr', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5100,
  serialized_end=5152,
)


_AIORANGE = _descriptor.Descriptor(
  name='AIORange',
  full_name='robotc.AIORange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='robotc.AIORange.min', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='robotc.AIORange.max', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5154,
  serialized_end=5190,
)


_RANGE = _descriptor.Descriptor(
  name='Range',
  full_name='robotc.Range',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='V', full_name='robotc.Range.V', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='A', full_name='robotc.Range.A', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5192,
  serialized_end=5257,
)


_MODBUSAIOGROUP = _descriptor.Descriptor(
  name='ModbusAioGroup',
  full_name='robotc.ModbusAioGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pins', full_name='robotc.ModbusAioGroup.pins', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addr', full_name='robotc.ModbusAioGroup.addr', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLsb', full_name='robotc.ModbusAioGroup.isLsb', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range', full_name='robotc.ModbusAioGroup.range', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='robotc.ModbusAioGroup.size', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5259,
  serialized_end=5381,
)


_MODBUSEXTERNALIOMAPPING = _descriptor.Descriptor(
  name='ModbusExternalIOMapping',
  full_name='robotc.ModbusExternalIOMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='di', full_name='robotc.ModbusExternalIOMapping.di', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do', full_name='robotc.ModbusExternalIOMapping.do', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ai', full_name='robotc.ModbusExternalIOMapping.ai', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ao', full_name='robotc.ModbusExternalIOMapping.ao', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5384,
  serialized_end=5553,
)


_MODBUSEXTERNALIO = _descriptor.Descriptor(
  name='ModbusExternalIO',
  full_name='robotc.ModbusExternalIO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ModbusExternalIO.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='robotc.ModbusExternalIO.ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='robotc.ModbusExternalIO.port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='robotc.ModbusExternalIO.timeout', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slaveId', full_name='robotc.ModbusExternalIO.slaveId', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmdHoldTime', full_name='robotc.ModbusExternalIO.cmdHoldTime', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='robotc.ModbusExternalIO.version', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ioMap', full_name='robotc.ModbusExternalIO.ioMap', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5556,
  serialized_end=5732,
)


_MODBUSEXTERNALIOS = _descriptor.Descriptor(
  name='ModbusExternalIOs',
  full_name='robotc.ModbusExternalIOs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ios', full_name='robotc.ModbusExternalIOs.ios', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5734,
  serialized_end=5792,
)


_RECORDPVATREQUEST_VZEROGAP = _descriptor.Descriptor(
  name='VZeroGap',
  full_name='robotc.RecordPVATRequest.VZeroGap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold', full_name='robotc.RecordPVATRequest.VZeroGap.threshold', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_gap', full_name='robotc.RecordPVATRequest.VZeroGap.remove_gap', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5982,
  serialized_end=6031,
)

_RECORDPVATREQUEST = _descriptor.Descriptor(
  name='RecordPVATRequest',
  full_name='robotc.RecordPVATRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='robotc.RecordPVATRequest.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='robotc.RecordPVATRequest.duration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vZeroGap', full_name='robotc.RecordPVATRequest.vZeroGap', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_duration_ts', full_name='robotc.RecordPVATRequest.use_duration_ts', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='save_file', full_name='robotc.RecordPVATRequest.save_file', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RECORDPVATREQUEST_VZEROGAP, ],
  enum_types=[
    _RECORDPVATREQUEST_PVATTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5795,
  serialized_end=6070,
)


_RECORDPVATRESPONSE = _descriptor.Descriptor(
  name='RecordPVATResponse',
  full_name='robotc.RecordPVATResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='p', full_name='robotc.RecordPVATResponse.p', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='robotc.RecordPVATResponse.v', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc', full_name='robotc.RecordPVATResponse.acc', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t', full_name='robotc.RecordPVATResponse.t', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='robotc.RecordPVATResponse.end', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='f', full_name='robotc.RecordPVATResponse.f', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6072,
  serialized_end=6162,
)

_ENABLEJOINTBACKLASHES.fields_by_name['joints'].message_type = _ENABLEJOINTBACKLASH
_EXTRASERVOPARAMS.fields_by_name['joints'].message_type = _EXTRASERVOPARAM
_JOINTBACKLASHES.fields_by_name['joints'].message_type = _JOINTBACKLASH
_JOINTBACKLASHPARAMS.fields_by_name['joints'].message_type = _JOINTBACKLASHPARAM
_JOINTCONFIGS.fields_by_name['configs'].message_type = _JOINTCONFIG
_SAFETYPLAT.fields_by_name['points'].message_type = messages__pb2._COORDINATE
_SAFETYPLATS.fields_by_name['plats'].message_type = _SAFETYPLAT
_LEDSTYLES.fields_by_name['styles'].message_type = _LEDSTYLE
_CONFIGURATION.fields_by_name['installDirection'].message_type = _INSTALLDIRECTION
_CONFIGURATION.fields_by_name['collisionDetector'].message_type = _COLLISIONDETECTOR
_CONFIGURATION.fields_by_name['jointConfigs'].message_type = _JOINTCONFIGS
_CONFIGURATION.fields_by_name['safetyPlats'].message_type = _SAFETYPLATS
_CONFIGURATION.fields_by_name['tcp'].message_type = messages__pb2._PR
_CONFIGURATION.fields_by_name['payload'].message_type = messages__pb2._PAYLOAD
_CONFIGURATION.fields_by_name['collisionTorqueDiff'].message_type = _COLLISIONTORQUEDIFF
_CONFIGURATION.fields_by_name['robotAIOInConfig'].message_type = messages__pb2._AIO
_CONFIGURATION.fields_by_name['robotAIOOutConfig'].message_type = messages__pb2._AIO
_CONFIGURATION.fields_by_name['styles'].message_type = _LEDSTYLE
_CONFIGURATION.fields_by_name['button_config'].message_type = _BUTTONCONFIG
_CONFIGURATION.fields_by_name['cartesianConfig'].message_type = _CARTESIANCONFIG
_CONFIGURATION.fields_by_name['extra_robotAIOInConfig'].message_type = messages__pb2._AIO
_CONFIGURATION.fields_by_name['extra_robotAIOOutConfig'].message_type = messages__pb2._AIO
_NOTICE.fields_by_name['type'].enum_type = _NOTICE_NOTICETYPE
_NOTICE.fields_by_name['id'].enum_type = _NOTICE_NOTICEID
_NOTICE_NOTICETYPE.containing_type = _NOTICE
_NOTICE_NOTICEID.containing_type = _NOTICE
_NOTIFICATION.fields_by_name['items'].message_type = _NOTICE
_DRIVER.fields_by_name['hardware'].message_type = messages__pb2._HARDWARE
_DRIVER.fields_by_name['curPartition'].enum_type = _BOOTPARTITION
_DRIVERINFO.fields_by_name['flange'].message_type = _DRIVER
_DRIVERINFO.fields_by_name['led'].message_type = _DRIVER
_DRIVERINFO.fields_by_name['joints'].message_type = _DRIVER
_DRIVERINFO.fields_by_name['comboard'].message_type = _DRIVER
_OTACMD.fields_by_name['bootloaderId'].enum_type = _BOOTLOADERID
_OTACMD.fields_by_name['targetPartition'].enum_type = _BOOTPARTITION
_OTADATA.fields_by_name['cmd'].message_type = _OTACMD
_OTADATA.fields_by_name['file'].message_type = _OTAFILE
_OTAJOINTS.fields_by_name['cmds'].message_type = _OTACMD
_OTAJOINTS.fields_by_name['file'].message_type = _OTAFILE
_OTADATAS.fields_by_name['joints'].message_type = _OTAJOINTS
_OTADATAS.fields_by_name['notJoints'].message_type = _OTADATA
_OTARESULT.fields_by_name['bootloaderId'].enum_type = _BOOTLOADERID
_OTARESULT.fields_by_name['partition'].enum_type = _BOOTPARTITION
_OTARESULTS.fields_by_name['results'].message_type = _OTARESULT
_JOINTSERVOPARAMS.fields_by_name['joints'].message_type = _JOINTSERVOPARAM
_DHPARAMS.fields_by_name['params'].message_type = _DHT
_FIXDHRESULT.fields_by_name['origin'].message_type = _DHT
_FIXDHRESULT.fields_by_name['before'].message_type = _DHT
_FIXDHRESULT.fields_by_name['after'].message_type = _DHT
_LUAEVENT.fields_by_name['type'].enum_type = _LUAEVENT_TYPE
_LUAEVENT.fields_by_name['cmd_state'].enum_type = _LUAEVENT_CMDSTATE
_LUAEVENT.fields_by_name['lua_state'].enum_type = messages__pb2._LUASTATE
_LUAEVENT.fields_by_name['options'].message_type = _OPTION
_LUAEVENT_TYPE.containing_type = _LUAEVENT
_LUAEVENT_CMDSTATE.containing_type = _LUAEVENT
_POSERES.fields_by_name['cart'].message_type = messages__pb2._PR
_POSERES.fields_by_name['joint'].message_type = messages__pb2._JPOSE
_MODBUSDIOGROUP.fields_by_name['pins'].message_type = _MODBUSDIO
_RANGE.fields_by_name['V'].message_type = _AIORANGE
_RANGE.fields_by_name['A'].message_type = _AIORANGE
_MODBUSAIOGROUP.fields_by_name['pins'].message_type = _MODBUSAIO
_MODBUSAIOGROUP.fields_by_name['range'].message_type = _RANGE
_MODBUSEXTERNALIOMAPPING.fields_by_name['di'].message_type = _MODBUSDIOGROUP
_MODBUSEXTERNALIOMAPPING.fields_by_name['do'].message_type = _MODBUSDIOGROUP
_MODBUSEXTERNALIOMAPPING.fields_by_name['ai'].message_type = _MODBUSAIOGROUP
_MODBUSEXTERNALIOMAPPING.fields_by_name['ao'].message_type = _MODBUSAIOGROUP
_MODBUSEXTERNALIO.fields_by_name['ioMap'].message_type = _MODBUSEXTERNALIOMAPPING
_MODBUSEXTERNALIOS.fields_by_name['ios'].message_type = _MODBUSEXTERNALIO
_RECORDPVATREQUEST_VZEROGAP.containing_type = _RECORDPVATREQUEST
_RECORDPVATREQUEST.fields_by_name['type'].enum_type = _RECORDPVATREQUEST_PVATTYPE
_RECORDPVATREQUEST.fields_by_name['vZeroGap'].message_type = _RECORDPVATREQUEST_VZEROGAP
_RECORDPVATREQUEST_PVATTYPE.containing_type = _RECORDPVATREQUEST
DESCRIPTOR.message_types_by_name['EnableJointBacklash'] = _ENABLEJOINTBACKLASH
DESCRIPTOR.message_types_by_name['EnableJointBacklashes'] = _ENABLEJOINTBACKLASHES
DESCRIPTOR.message_types_by_name['ExtraServoParam'] = _EXTRASERVOPARAM
DESCRIPTOR.message_types_by_name['ExtraServoParams'] = _EXTRASERVOPARAMS
DESCRIPTOR.message_types_by_name['JointBacklash'] = _JOINTBACKLASH
DESCRIPTOR.message_types_by_name['JointBacklashes'] = _JOINTBACKLASHES
DESCRIPTOR.message_types_by_name['JointBacklashParam'] = _JOINTBACKLASHPARAM
DESCRIPTOR.message_types_by_name['JointBacklashParams'] = _JOINTBACKLASHPARAMS
DESCRIPTOR.message_types_by_name['VoiceFile'] = _VOICEFILE
DESCRIPTOR.message_types_by_name['VoiceResult'] = _VOICERESULT
DESCRIPTOR.message_types_by_name['TrueOrFalse'] = _TRUEORFALSE
DESCRIPTOR.message_types_by_name['InstallDirection'] = _INSTALLDIRECTION
DESCRIPTOR.message_types_by_name['JointConfig'] = _JOINTCONFIG
DESCRIPTOR.message_types_by_name['JointConfigs'] = _JOINTCONFIGS
DESCRIPTOR.message_types_by_name['CartesianConfig'] = _CARTESIANCONFIG
DESCRIPTOR.message_types_by_name['SafetyPlat'] = _SAFETYPLAT
DESCRIPTOR.message_types_by_name['SafetyPlats'] = _SAFETYPLATS
DESCRIPTOR.message_types_by_name['CollisionTorqueDiff'] = _COLLISIONTORQUEDIFF
DESCRIPTOR.message_types_by_name['CollisionDetector'] = _COLLISIONDETECTOR
DESCRIPTOR.message_types_by_name['LEDStyle'] = _LEDSTYLE
DESCRIPTOR.message_types_by_name['LEDStyles'] = _LEDSTYLES
DESCRIPTOR.message_types_by_name['ButtonConfig'] = _BUTTONCONFIG
DESCRIPTOR.message_types_by_name['Configuration'] = _CONFIGURATION
DESCRIPTOR.message_types_by_name['Zero'] = _ZERO
DESCRIPTOR.message_types_by_name['Notice'] = _NOTICE
DESCRIPTOR.message_types_by_name['Notification'] = _NOTIFICATION
DESCRIPTOR.message_types_by_name['Driver'] = _DRIVER
DESCRIPTOR.message_types_by_name['DriverInfo'] = _DRIVERINFO
DESCRIPTOR.message_types_by_name['OTAFile'] = _OTAFILE
DESCRIPTOR.message_types_by_name['OTACmd'] = _OTACMD
DESCRIPTOR.message_types_by_name['OTAData'] = _OTADATA
DESCRIPTOR.message_types_by_name['OTAJoints'] = _OTAJOINTS
DESCRIPTOR.message_types_by_name['OTADatas'] = _OTADATAS
DESCRIPTOR.message_types_by_name['OTAResult'] = _OTARESULT
DESCRIPTOR.message_types_by_name['OTAResults'] = _OTARESULTS
DESCRIPTOR.message_types_by_name['CurrentVoltage'] = _CURRENTVOLTAGE
DESCRIPTOR.message_types_by_name['JointServoParam'] = _JOINTSERVOPARAM
DESCRIPTOR.message_types_by_name['JointServoParams'] = _JOINTSERVOPARAMS
DESCRIPTOR.message_types_by_name['DebugParams'] = _DEBUGPARAMS
DESCRIPTOR.message_types_by_name['FixDHRequest'] = _FIXDHREQUEST
DESCRIPTOR.message_types_by_name['DHRequest'] = _DHREQUEST
DESCRIPTOR.message_types_by_name['DHt'] = _DHT
DESCRIPTOR.message_types_by_name['DHParams'] = _DHPARAMS
DESCRIPTOR.message_types_by_name['FixDHResult'] = _FIXDHRESULT
DESCRIPTOR.message_types_by_name['Option'] = _OPTION
DESCRIPTOR.message_types_by_name['LuaEvent'] = _LUAEVENT
DESCRIPTOR.message_types_by_name['ConfirmInput'] = _CONFIRMINPUT
DESCRIPTOR.message_types_by_name['PoseRes'] = _POSERES
DESCRIPTOR.message_types_by_name['ModbusDio'] = _MODBUSDIO
DESCRIPTOR.message_types_by_name['ModbusDioGroup'] = _MODBUSDIOGROUP
DESCRIPTOR.message_types_by_name['ModbusAio'] = _MODBUSAIO
DESCRIPTOR.message_types_by_name['AIORange'] = _AIORANGE
DESCRIPTOR.message_types_by_name['Range'] = _RANGE
DESCRIPTOR.message_types_by_name['ModbusAioGroup'] = _MODBUSAIOGROUP
DESCRIPTOR.message_types_by_name['ModbusExternalIOMapping'] = _MODBUSEXTERNALIOMAPPING
DESCRIPTOR.message_types_by_name['ModbusExternalIO'] = _MODBUSEXTERNALIO
DESCRIPTOR.message_types_by_name['ModbusExternalIOs'] = _MODBUSEXTERNALIOS
DESCRIPTOR.message_types_by_name['RecordPVATRequest'] = _RECORDPVATREQUEST
DESCRIPTOR.message_types_by_name['RecordPVATResponse'] = _RECORDPVATRESPONSE
DESCRIPTOR.enum_types_by_name['BootloaderId'] = _BOOTLOADERID
DESCRIPTOR.enum_types_by_name['BootPartition'] = _BOOTPARTITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EnableJointBacklash = _reflection.GeneratedProtocolMessageType('EnableJointBacklash', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEJOINTBACKLASH,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.EnableJointBacklash)
  })
_sym_db.RegisterMessage(EnableJointBacklash)

EnableJointBacklashes = _reflection.GeneratedProtocolMessageType('EnableJointBacklashes', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEJOINTBACKLASHES,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.EnableJointBacklashes)
  })
_sym_db.RegisterMessage(EnableJointBacklashes)

ExtraServoParam = _reflection.GeneratedProtocolMessageType('ExtraServoParam', (_message.Message,), {
  'DESCRIPTOR' : _EXTRASERVOPARAM,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExtraServoParam)
  })
_sym_db.RegisterMessage(ExtraServoParam)

ExtraServoParams = _reflection.GeneratedProtocolMessageType('ExtraServoParams', (_message.Message,), {
  'DESCRIPTOR' : _EXTRASERVOPARAMS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ExtraServoParams)
  })
_sym_db.RegisterMessage(ExtraServoParams)

JointBacklash = _reflection.GeneratedProtocolMessageType('JointBacklash', (_message.Message,), {
  'DESCRIPTOR' : _JOINTBACKLASH,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointBacklash)
  })
_sym_db.RegisterMessage(JointBacklash)

JointBacklashes = _reflection.GeneratedProtocolMessageType('JointBacklashes', (_message.Message,), {
  'DESCRIPTOR' : _JOINTBACKLASHES,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointBacklashes)
  })
_sym_db.RegisterMessage(JointBacklashes)

JointBacklashParam = _reflection.GeneratedProtocolMessageType('JointBacklashParam', (_message.Message,), {
  'DESCRIPTOR' : _JOINTBACKLASHPARAM,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointBacklashParam)
  })
_sym_db.RegisterMessage(JointBacklashParam)

JointBacklashParams = _reflection.GeneratedProtocolMessageType('JointBacklashParams', (_message.Message,), {
  'DESCRIPTOR' : _JOINTBACKLASHPARAMS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointBacklashParams)
  })
_sym_db.RegisterMessage(JointBacklashParams)

VoiceFile = _reflection.GeneratedProtocolMessageType('VoiceFile', (_message.Message,), {
  'DESCRIPTOR' : _VOICEFILE,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.VoiceFile)
  })
_sym_db.RegisterMessage(VoiceFile)

VoiceResult = _reflection.GeneratedProtocolMessageType('VoiceResult', (_message.Message,), {
  'DESCRIPTOR' : _VOICERESULT,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.VoiceResult)
  })
_sym_db.RegisterMessage(VoiceResult)

TrueOrFalse = _reflection.GeneratedProtocolMessageType('TrueOrFalse', (_message.Message,), {
  'DESCRIPTOR' : _TRUEORFALSE,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.TrueOrFalse)
  })
_sym_db.RegisterMessage(TrueOrFalse)

InstallDirection = _reflection.GeneratedProtocolMessageType('InstallDirection', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLDIRECTION,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.InstallDirection)
  })
_sym_db.RegisterMessage(InstallDirection)

JointConfig = _reflection.GeneratedProtocolMessageType('JointConfig', (_message.Message,), {
  'DESCRIPTOR' : _JOINTCONFIG,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointConfig)
  })
_sym_db.RegisterMessage(JointConfig)

JointConfigs = _reflection.GeneratedProtocolMessageType('JointConfigs', (_message.Message,), {
  'DESCRIPTOR' : _JOINTCONFIGS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointConfigs)
  })
_sym_db.RegisterMessage(JointConfigs)

CartesianConfig = _reflection.GeneratedProtocolMessageType('CartesianConfig', (_message.Message,), {
  'DESCRIPTOR' : _CARTESIANCONFIG,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.CartesianConfig)
  })
_sym_db.RegisterMessage(CartesianConfig)

SafetyPlat = _reflection.GeneratedProtocolMessageType('SafetyPlat', (_message.Message,), {
  'DESCRIPTOR' : _SAFETYPLAT,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SafetyPlat)
  })
_sym_db.RegisterMessage(SafetyPlat)

SafetyPlats = _reflection.GeneratedProtocolMessageType('SafetyPlats', (_message.Message,), {
  'DESCRIPTOR' : _SAFETYPLATS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SafetyPlats)
  })
_sym_db.RegisterMessage(SafetyPlats)

CollisionTorqueDiff = _reflection.GeneratedProtocolMessageType('CollisionTorqueDiff', (_message.Message,), {
  'DESCRIPTOR' : _COLLISIONTORQUEDIFF,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.CollisionTorqueDiff)
  })
_sym_db.RegisterMessage(CollisionTorqueDiff)

CollisionDetector = _reflection.GeneratedProtocolMessageType('CollisionDetector', (_message.Message,), {
  'DESCRIPTOR' : _COLLISIONDETECTOR,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.CollisionDetector)
  })
_sym_db.RegisterMessage(CollisionDetector)

LEDStyle = _reflection.GeneratedProtocolMessageType('LEDStyle', (_message.Message,), {
  'DESCRIPTOR' : _LEDSTYLE,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.LEDStyle)
  })
_sym_db.RegisterMessage(LEDStyle)

LEDStyles = _reflection.GeneratedProtocolMessageType('LEDStyles', (_message.Message,), {
  'DESCRIPTOR' : _LEDSTYLES,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.LEDStyles)
  })
_sym_db.RegisterMessage(LEDStyles)

ButtonConfig = _reflection.GeneratedProtocolMessageType('ButtonConfig', (_message.Message,), {
  'DESCRIPTOR' : _BUTTONCONFIG,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ButtonConfig)
  })
_sym_db.RegisterMessage(ButtonConfig)

Configuration = _reflection.GeneratedProtocolMessageType('Configuration', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURATION,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Configuration)
  })
_sym_db.RegisterMessage(Configuration)

Zero = _reflection.GeneratedProtocolMessageType('Zero', (_message.Message,), {
  'DESCRIPTOR' : _ZERO,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Zero)
  })
_sym_db.RegisterMessage(Zero)

Notice = _reflection.GeneratedProtocolMessageType('Notice', (_message.Message,), {
  'DESCRIPTOR' : _NOTICE,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Notice)
  })
_sym_db.RegisterMessage(Notice)

Notification = _reflection.GeneratedProtocolMessageType('Notification', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATION,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Notification)
  })
_sym_db.RegisterMessage(Notification)

Driver = _reflection.GeneratedProtocolMessageType('Driver', (_message.Message,), {
  'DESCRIPTOR' : _DRIVER,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Driver)
  })
_sym_db.RegisterMessage(Driver)

DriverInfo = _reflection.GeneratedProtocolMessageType('DriverInfo', (_message.Message,), {
  'DESCRIPTOR' : _DRIVERINFO,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DriverInfo)
  })
_sym_db.RegisterMessage(DriverInfo)

OTAFile = _reflection.GeneratedProtocolMessageType('OTAFile', (_message.Message,), {
  'DESCRIPTOR' : _OTAFILE,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.OTAFile)
  })
_sym_db.RegisterMessage(OTAFile)

OTACmd = _reflection.GeneratedProtocolMessageType('OTACmd', (_message.Message,), {
  'DESCRIPTOR' : _OTACMD,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.OTACmd)
  })
_sym_db.RegisterMessage(OTACmd)

OTAData = _reflection.GeneratedProtocolMessageType('OTAData', (_message.Message,), {
  'DESCRIPTOR' : _OTADATA,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.OTAData)
  })
_sym_db.RegisterMessage(OTAData)

OTAJoints = _reflection.GeneratedProtocolMessageType('OTAJoints', (_message.Message,), {
  'DESCRIPTOR' : _OTAJOINTS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.OTAJoints)
  })
_sym_db.RegisterMessage(OTAJoints)

OTADatas = _reflection.GeneratedProtocolMessageType('OTADatas', (_message.Message,), {
  'DESCRIPTOR' : _OTADATAS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.OTADatas)
  })
_sym_db.RegisterMessage(OTADatas)

OTAResult = _reflection.GeneratedProtocolMessageType('OTAResult', (_message.Message,), {
  'DESCRIPTOR' : _OTARESULT,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.OTAResult)
  })
_sym_db.RegisterMessage(OTAResult)

OTAResults = _reflection.GeneratedProtocolMessageType('OTAResults', (_message.Message,), {
  'DESCRIPTOR' : _OTARESULTS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.OTAResults)
  })
_sym_db.RegisterMessage(OTAResults)

CurrentVoltage = _reflection.GeneratedProtocolMessageType('CurrentVoltage', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTVOLTAGE,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.CurrentVoltage)
  })
_sym_db.RegisterMessage(CurrentVoltage)

JointServoParam = _reflection.GeneratedProtocolMessageType('JointServoParam', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSERVOPARAM,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointServoParam)
  })
_sym_db.RegisterMessage(JointServoParam)

JointServoParams = _reflection.GeneratedProtocolMessageType('JointServoParams', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSERVOPARAMS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointServoParams)
  })
_sym_db.RegisterMessage(JointServoParams)

DebugParams = _reflection.GeneratedProtocolMessageType('DebugParams', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGPARAMS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DebugParams)
  })
_sym_db.RegisterMessage(DebugParams)

FixDHRequest = _reflection.GeneratedProtocolMessageType('FixDHRequest', (_message.Message,), {
  'DESCRIPTOR' : _FIXDHREQUEST,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.FixDHRequest)
  })
_sym_db.RegisterMessage(FixDHRequest)

DHRequest = _reflection.GeneratedProtocolMessageType('DHRequest', (_message.Message,), {
  'DESCRIPTOR' : _DHREQUEST,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DHRequest)
  })
_sym_db.RegisterMessage(DHRequest)

DHt = _reflection.GeneratedProtocolMessageType('DHt', (_message.Message,), {
  'DESCRIPTOR' : _DHT,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DHt)
  })
_sym_db.RegisterMessage(DHt)

DHParams = _reflection.GeneratedProtocolMessageType('DHParams', (_message.Message,), {
  'DESCRIPTOR' : _DHPARAMS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DHParams)
  })
_sym_db.RegisterMessage(DHParams)

FixDHResult = _reflection.GeneratedProtocolMessageType('FixDHResult', (_message.Message,), {
  'DESCRIPTOR' : _FIXDHRESULT,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.FixDHResult)
  })
_sym_db.RegisterMessage(FixDHResult)

Option = _reflection.GeneratedProtocolMessageType('Option', (_message.Message,), {
  'DESCRIPTOR' : _OPTION,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Option)
  })
_sym_db.RegisterMessage(Option)

LuaEvent = _reflection.GeneratedProtocolMessageType('LuaEvent', (_message.Message,), {
  'DESCRIPTOR' : _LUAEVENT,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.LuaEvent)
  })
_sym_db.RegisterMessage(LuaEvent)

ConfirmInput = _reflection.GeneratedProtocolMessageType('ConfirmInput', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMINPUT,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ConfirmInput)
  })
_sym_db.RegisterMessage(ConfirmInput)

PoseRes = _reflection.GeneratedProtocolMessageType('PoseRes', (_message.Message,), {
  'DESCRIPTOR' : _POSERES,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.PoseRes)
  })
_sym_db.RegisterMessage(PoseRes)

ModbusDio = _reflection.GeneratedProtocolMessageType('ModbusDio', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSDIO,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ModbusDio)
  })
_sym_db.RegisterMessage(ModbusDio)

ModbusDioGroup = _reflection.GeneratedProtocolMessageType('ModbusDioGroup', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSDIOGROUP,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ModbusDioGroup)
  })
_sym_db.RegisterMessage(ModbusDioGroup)

ModbusAio = _reflection.GeneratedProtocolMessageType('ModbusAio', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSAIO,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ModbusAio)
  })
_sym_db.RegisterMessage(ModbusAio)

AIORange = _reflection.GeneratedProtocolMessageType('AIORange', (_message.Message,), {
  'DESCRIPTOR' : _AIORANGE,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.AIORange)
  })
_sym_db.RegisterMessage(AIORange)

Range = _reflection.GeneratedProtocolMessageType('Range', (_message.Message,), {
  'DESCRIPTOR' : _RANGE,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Range)
  })
_sym_db.RegisterMessage(Range)

ModbusAioGroup = _reflection.GeneratedProtocolMessageType('ModbusAioGroup', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSAIOGROUP,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ModbusAioGroup)
  })
_sym_db.RegisterMessage(ModbusAioGroup)

ModbusExternalIOMapping = _reflection.GeneratedProtocolMessageType('ModbusExternalIOMapping', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSEXTERNALIOMAPPING,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ModbusExternalIOMapping)
  })
_sym_db.RegisterMessage(ModbusExternalIOMapping)

ModbusExternalIO = _reflection.GeneratedProtocolMessageType('ModbusExternalIO', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSEXTERNALIO,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ModbusExternalIO)
  })
_sym_db.RegisterMessage(ModbusExternalIO)

ModbusExternalIOs = _reflection.GeneratedProtocolMessageType('ModbusExternalIOs', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSEXTERNALIOS,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ModbusExternalIOs)
  })
_sym_db.RegisterMessage(ModbusExternalIOs)

RecordPVATRequest = _reflection.GeneratedProtocolMessageType('RecordPVATRequest', (_message.Message,), {

  'VZeroGap' : _reflection.GeneratedProtocolMessageType('VZeroGap', (_message.Message,), {
    'DESCRIPTOR' : _RECORDPVATREQUEST_VZEROGAP,
    '__module__' : 'private_controller_pb2'
    # @@protoc_insertion_point(class_scope:robotc.RecordPVATRequest.VZeroGap)
    })
  ,
  'DESCRIPTOR' : _RECORDPVATREQUEST,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RecordPVATRequest)
  })
_sym_db.RegisterMessage(RecordPVATRequest)
_sym_db.RegisterMessage(RecordPVATRequest.VZeroGap)

RecordPVATResponse = _reflection.GeneratedProtocolMessageType('RecordPVATResponse', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPVATRESPONSE,
  '__module__' : 'private_controller_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RecordPVATResponse)
  })
_sym_db.RegisterMessage(RecordPVATResponse)



_ROBOTPRIVATECONTROLLER = _descriptor.ServiceDescriptor(
  name='RobotPrivateController',
  full_name='robotc.RobotPrivateController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=6391,
  serialized_end=9890,
  methods=[
  _descriptor.MethodDescriptor(
    name='Init',
    full_name='robotc.RobotPrivateController.Init',
    index=0,
    containing_service=None,
    input_type=_CONFIGURATION,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRobotInfo',
    full_name='robotc.RobotPrivateController.GetRobotInfo',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=messages__pb2._ROBOTINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetInstallDirection',
    full_name='robotc.RobotPrivateController.SetInstallDirection',
    index=2,
    containing_service=None,
    input_type=_INSTALLDIRECTION,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetCollisionDetector',
    full_name='robotc.RobotPrivateController.SetCollisionDetector',
    index=3,
    containing_service=None,
    input_type=_COLLISIONDETECTOR,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetJointConfig',
    full_name='robotc.RobotPrivateController.SetJointConfig',
    index=4,
    containing_service=None,
    input_type=_JOINTCONFIGS,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetCartesianConfig',
    full_name='robotc.RobotPrivateController.SetCartesianConfig',
    index=5,
    containing_service=None,
    input_type=_CARTESIANCONFIG,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnableDDS',
    full_name='robotc.RobotPrivateController.EnableDDS',
    index=6,
    containing_service=None,
    input_type=_TRUEORFALSE,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetCollisionTorqueDiff',
    full_name='robotc.RobotPrivateController.SetCollisionTorqueDiff',
    index=7,
    containing_service=None,
    input_type=_COLLISIONTORQUEDIFF,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterNotification',
    full_name='robotc.RobotPrivateController.RegisterNotification',
    index=8,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_NOTIFICATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RobotDriverInfo',
    full_name='robotc.RobotPrivateController.RobotDriverInfo',
    index=9,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_DRIVERINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RobotOTA',
    full_name='robotc.RobotPrivateController.RobotOTA',
    index=10,
    containing_service=None,
    input_type=_OTADATA,
    output_type=_OTARESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SwitchOtaPartition',
    full_name='robotc.RobotPrivateController.SwitchOtaPartition',
    index=11,
    containing_service=None,
    input_type=_OTACMD,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RobotOTABatch',
    full_name='robotc.RobotPrivateController.RobotOTABatch',
    index=12,
    containing_service=None,
    input_type=_OTADATAS,
    output_type=_OTARESULTS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Reset',
    full_name='robotc.RobotPrivateController.Reset',
    index=13,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InitZero',
    full_name='robotc.RobotPrivateController.InitZero',
    index=14,
    containing_service=None,
    input_type=_ZERO,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetZero',
    full_name='robotc.RobotPrivateController.SetZero',
    index=15,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVoltage',
    full_name='robotc.RobotPrivateController.GetVoltage',
    index=16,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CURRENTVOLTAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoParam',
    full_name='robotc.RobotPrivateController.SetServoParam',
    index=17,
    containing_service=None,
    input_type=_JOINTSERVOPARAM,
    output_type=_JOINTSERVOPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoParams',
    full_name='robotc.RobotPrivateController.GetServoParams',
    index=18,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINTSERVOPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDebugParams',
    full_name='robotc.RobotPrivateController.SetDebugParams',
    index=19,
    containing_service=None,
    input_type=_DEBUGPARAMS,
    output_type=_DEBUGPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FixDHParams',
    full_name='robotc.RobotPrivateController.FixDHParams',
    index=20,
    containing_service=None,
    input_type=_FIXDHREQUEST,
    output_type=_FIXDHRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetLEDStyle',
    full_name='robotc.RobotPrivateController.SetLEDStyle',
    index=21,
    containing_service=None,
    input_type=_LEDSTYLE,
    output_type=_LEDSTYLES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLEDStyles',
    full_name='robotc.RobotPrivateController.GetLEDStyles',
    index=22,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LEDSTYLES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterLuaEvent',
    full_name='robotc.RobotPrivateController.RegisterLuaEvent',
    index=23,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LUAEVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfirmCallback',
    full_name='robotc.RobotPrivateController.ConfirmCallback',
    index=24,
    containing_service=None,
    input_type=_CONFIRMINPUT,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLastPose',
    full_name='robotc.RobotPrivateController.GetLastPose',
    index=25,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_POSERES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetModbusExternalIO',
    full_name='robotc.RobotPrivateController.SetModbusExternalIO',
    index=26,
    containing_service=None,
    input_type=_MODBUSEXTERNALIOS,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetButtonConfig',
    full_name='robotc.RobotPrivateController.SetButtonConfig',
    index=27,
    containing_service=None,
    input_type=_BUTTONCONFIG,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetBreakACup',
    full_name='robotc.RobotPrivateController.SetBreakACup',
    index=28,
    containing_service=None,
    input_type=_TRUEORFALSE,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RecordPVAT',
    full_name='robotc.RobotPrivateController.RecordPVAT',
    index=29,
    containing_service=None,
    input_type=_RECORDPVATREQUEST,
    output_type=_RECORDPVATRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopRecordPVAT',
    full_name='robotc.RobotPrivateController.StopRecordPVAT',
    index=30,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpgradeVoiceFile',
    full_name='robotc.RobotPrivateController.UpgradeVoiceFile',
    index=31,
    containing_service=None,
    input_type=_VOICEFILE,
    output_type=_VOICERESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDHParams',
    full_name='robotc.RobotPrivateController.GetDHParams',
    index=32,
    containing_service=None,
    input_type=_DHREQUEST,
    output_type=_DHPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDHParams',
    full_name='robotc.RobotPrivateController.SetDHParams',
    index=33,
    containing_service=None,
    input_type=_DHPARAMS,
    output_type=_DHPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteExtraServoParam',
    full_name='robotc.RobotPrivateController.WriteExtraServoParam',
    index=34,
    containing_service=None,
    input_type=_EXTRASERVOPARAM,
    output_type=_EXTRASERVOPARAM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadExtraServoParam',
    full_name='robotc.RobotPrivateController.ReadExtraServoParam',
    index=35,
    containing_service=None,
    input_type=_EXTRASERVOPARAM,
    output_type=_EXTRASERVOPARAM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteExtraServoParams',
    full_name='robotc.RobotPrivateController.WriteExtraServoParams',
    index=36,
    containing_service=None,
    input_type=_EXTRASERVOPARAM,
    output_type=_EXTRASERVOPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadExtraServoParams',
    full_name='robotc.RobotPrivateController.ReadExtraServoParams',
    index=37,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_EXTRASERVOPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetExtraServoParams',
    full_name='robotc.RobotPrivateController.ResetExtraServoParams',
    index=38,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_EXTRASERVOPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteJointBacklash',
    full_name='robotc.RobotPrivateController.WriteJointBacklash',
    index=39,
    containing_service=None,
    input_type=_JOINTBACKLASH,
    output_type=_JOINTBACKLASH,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadJointBacklash',
    full_name='robotc.RobotPrivateController.ReadJointBacklash',
    index=40,
    containing_service=None,
    input_type=_JOINTBACKLASH,
    output_type=_JOINTBACKLASH,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteJointBacklashes',
    full_name='robotc.RobotPrivateController.WriteJointBacklashes',
    index=41,
    containing_service=None,
    input_type=_JOINTBACKLASH,
    output_type=_JOINTBACKLASHES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadJointBacklashes',
    full_name='robotc.RobotPrivateController.ReadJointBacklashes',
    index=42,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINTBACKLASHES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetJointBacklashes',
    full_name='robotc.RobotPrivateController.ResetJointBacklashes',
    index=43,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINTBACKLASHES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteEnableJointBacklashes',
    full_name='robotc.RobotPrivateController.WriteEnableJointBacklashes',
    index=44,
    containing_service=None,
    input_type=_ENABLEJOINTBACKLASH,
    output_type=_ENABLEJOINTBACKLASHES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadEnableJointBacklashes',
    full_name='robotc.RobotPrivateController.ReadEnableJointBacklashes',
    index=45,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_ENABLEJOINTBACKLASHES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetEnableJointBacklashes',
    full_name='robotc.RobotPrivateController.ResetEnableJointBacklashes',
    index=46,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_ENABLEJOINTBACKLASHES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteJointBacklashParam',
    full_name='robotc.RobotPrivateController.WriteJointBacklashParam',
    index=47,
    containing_service=None,
    input_type=_JOINTBACKLASHPARAM,
    output_type=_JOINTBACKLASHPARAM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadJointBacklashParam',
    full_name='robotc.RobotPrivateController.ReadJointBacklashParam',
    index=48,
    containing_service=None,
    input_type=_JOINTBACKLASHPARAM,
    output_type=_JOINTBACKLASHPARAM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteJointBacklashParams',
    full_name='robotc.RobotPrivateController.WriteJointBacklashParams',
    index=49,
    containing_service=None,
    input_type=_JOINTBACKLASHPARAM,
    output_type=_JOINTBACKLASHPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadJointBacklashParams',
    full_name='robotc.RobotPrivateController.ReadJointBacklashParams',
    index=50,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINTBACKLASHPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetJointBacklashParams',
    full_name='robotc.RobotPrivateController.ResetJointBacklashParams',
    index=51,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINTBACKLASHPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnableJointLimit',
    full_name='robotc.RobotPrivateController.EnableJointLimit',
    index=52,
    containing_service=None,
    input_type=_TRUEORFALSE,
    output_type=messages__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROBOTPRIVATECONTROLLER)

DESCRIPTOR.services_by_name['RobotPrivateController'] = _ROBOTPRIVATECONTROLLER

# @@protoc_insertion_point(module_scope)
